# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.sprite import Sprite
from bitmovin_api_sdk.encoding.encodings.streams.sprites.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.sprites.sprite_list_query_params import SpriteListQueryParams


class SpritesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(SpritesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, stream_id, sprite, **kwargs):
        # type: (string_types, string_types, Sprite, dict) -> Sprite
        """Add Sprite

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param sprite: The Sprite to be added
        :type sprite: Sprite, required
        :return: Sprite details
        :rtype: Sprite
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/sprites',
            sprite,
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            type=Sprite,
            **kwargs
        )

    def delete(self, encoding_id, stream_id, sprite_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete Sprite

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param sprite_id: Id of the sprite.
        :type sprite_id: string_types, required
        :return: Id of the sprite
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/sprites/{sprite_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'sprite_id': sprite_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, stream_id, sprite_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> Sprite
        """Sprite Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param sprite_id: Id of the sprite configuration.
        :type sprite_id: string_types, required
        :return: Sprite details
        :rtype: Sprite
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/sprites/{sprite_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id, 'sprite_id': sprite_id},
            type=Sprite,
            **kwargs
        )

    def list(self, encoding_id, stream_id, query_params=None, **kwargs):
        # type: (string_types, string_types, SpriteListQueryParams, dict) -> Sprite
        """List Sprites

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :param query_params: Query parameters
        :type query_params: SpriteListQueryParams
        :return: List of sprites
        :rtype: Sprite
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}/sprites',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            query_params=query_params,
            pagination_response=True,
            type=Sprite,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class H264Partition(Enum):
    NONE = "NONE"
    P8X8 = "P8X8"
    P4X4 = "P4X4"
    B8X8 = "B8X8"
    I8X8 = "I8X8"
    I4X4 = "I4X4"
    ALL = "ALL"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.custom_data import CustomData
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class CustomdataApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(CustomdataApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, configuration_id, **kwargs):
        # type: (string_types, dict) -> CustomData
        """HE-AAC v1 Codec Configuration Custom Data

        :param configuration_id: Id of the codec configuration
        :type configuration_id: string_types, required
        :return: HE-AAC v1 codec configuration custom data
        :rtype: CustomData
        """

        return self.api_client.get(
            '/encoding/configurations/audio/he-aac-v1/{configuration_id}/customData',
            path_params={'configuration_id': configuration_id},
            type=CustomData,
            **kwargs
        )



from bitmovin_api_sdk.encoding.manifests.hls.hls_api import HlsApi
from bitmovin_api_sdk.encoding.manifests.hls.default.default_api import DefaultApi
from bitmovin_api_sdk.encoding.manifests.hls.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.manifests.hls.streams.streams_api import StreamsApi
from bitmovin_api_sdk.encoding.manifests.hls.media.media_api import MediaApi
from bitmovin_api_sdk.encoding.manifests.hls.hls_manifest_list_query_params import HlsManifestListQueryParams



from bitmovin_api_sdk.encoding.encodings.input_streams.dolby_vision.dolby_vision_api import DolbyVisionApi
from bitmovin_api_sdk.encoding.encodings.input_streams.dolby_vision.dolby_vision_input_stream_list_query_params import DolbyVisionInputStreamListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.passthrough_mode import PassthroughMode
import pprint
import six


class Cea608708SubtitleConfiguration(object):
    @poscheck_model
    def __init__(self,
                 passthrough_activated=None,
                 passthrough_mode=None):
        # type: (bool, PassthroughMode) -> None

        self._passthrough_activated = None
        self._passthrough_mode = None
        self.discriminator = None

        if passthrough_activated is not None:
            self.passthrough_activated = passthrough_activated
        if passthrough_mode is not None:
            self.passthrough_mode = passthrough_mode

    @property
    def openapi_types(self):
        types = {
            'passthrough_activated': 'bool',
            'passthrough_mode': 'PassthroughMode'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'passthrough_activated': 'passthroughActivated',
            'passthrough_mode': 'passthroughMode'
        }
        return attributes

    @property
    def passthrough_activated(self):
        # type: () -> bool
        """Gets the passthrough_activated of this Cea608708SubtitleConfiguration.

        If enabled, CEA 608 an CEA 708 subtitles will be copied from the input video stream to the output video stream. Note: This does not work, if the output framerate is different than the input framerate (except doubling the framerate with deinterlacing per field)

        :return: The passthrough_activated of this Cea608708SubtitleConfiguration.
        :rtype: bool
        """
        return self._passthrough_activated

    @passthrough_activated.setter
    def passthrough_activated(self, passthrough_activated):
        # type: (bool) -> None
        """Sets the passthrough_activated of this Cea608708SubtitleConfiguration.

        If enabled, CEA 608 an CEA 708 subtitles will be copied from the input video stream to the output video stream. Note: This does not work, if the output framerate is different than the input framerate (except doubling the framerate with deinterlacing per field)

        :param passthrough_activated: The passthrough_activated of this Cea608708SubtitleConfiguration.
        :type: bool
        """

        if passthrough_activated is not None:
            if not isinstance(passthrough_activated, bool):
                raise TypeError("Invalid type for `passthrough_activated`, type has to be `bool`")

        self._passthrough_activated = passthrough_activated

    @property
    def passthrough_mode(self):
        # type: () -> PassthroughMode
        """Gets the passthrough_mode of this Cea608708SubtitleConfiguration.


        :return: The passthrough_mode of this Cea608708SubtitleConfiguration.
        :rtype: PassthroughMode
        """
        return self._passthrough_mode

    @passthrough_mode.setter
    def passthrough_mode(self, passthrough_mode):
        # type: (PassthroughMode) -> None
        """Sets the passthrough_mode of this Cea608708SubtitleConfiguration.


        :param passthrough_mode: The passthrough_mode of this Cea608708SubtitleConfiguration.
        :type: PassthroughMode
        """

        if passthrough_mode is not None:
            if not isinstance(passthrough_mode, PassthroughMode):
                raise TypeError("Invalid type for `passthrough_mode`, type has to be `PassthroughMode`")

        self._passthrough_mode = passthrough_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Cea608708SubtitleConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class DisplayAspectRatio(object):
    @poscheck_model
    def __init__(self,
                 numerator=None,
                 denominator=None):
        # type: (int, int) -> None

        self._numerator = None
        self._denominator = None
        self.discriminator = None

        if numerator is not None:
            self.numerator = numerator
        if denominator is not None:
            self.denominator = denominator

    @property
    def openapi_types(self):
        types = {
            'numerator': 'int',
            'denominator': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'numerator': 'numerator',
            'denominator': 'denominator'
        }
        return attributes

    @property
    def numerator(self):
        # type: () -> int
        """Gets the numerator of this DisplayAspectRatio.

        The numerator of the display aspect ratio (DAR). For example for a DAR of 16:9, the value 16 must be used. (required)

        :return: The numerator of this DisplayAspectRatio.
        :rtype: int
        """
        return self._numerator

    @numerator.setter
    def numerator(self, numerator):
        # type: (int) -> None
        """Sets the numerator of this DisplayAspectRatio.

        The numerator of the display aspect ratio (DAR). For example for a DAR of 16:9, the value 16 must be used. (required)

        :param numerator: The numerator of this DisplayAspectRatio.
        :type: int
        """

        if numerator is not None:
            if numerator is not None and numerator < 1:
                raise ValueError("Invalid value for `numerator`, must be a value greater than or equal to `1`")
            if not isinstance(numerator, int):
                raise TypeError("Invalid type for `numerator`, type has to be `int`")

        self._numerator = numerator

    @property
    def denominator(self):
        # type: () -> int
        """Gets the denominator of this DisplayAspectRatio.

        The denominator of the display aspect ratio (DAR). For example for a DAR of 16:9, the value 9 must be used. (required)

        :return: The denominator of this DisplayAspectRatio.
        :rtype: int
        """
        return self._denominator

    @denominator.setter
    def denominator(self, denominator):
        # type: (int) -> None
        """Sets the denominator of this DisplayAspectRatio.

        The denominator of the display aspect ratio (DAR). For example for a DAR of 16:9, the value 9 must be used. (required)

        :param denominator: The denominator of this DisplayAspectRatio.
        :type: int
        """

        if denominator is not None:
            if denominator is not None and denominator < 1:
                raise ValueError("Invalid value for `denominator`, must be a value greater than or equal to `1`")
            if not isinstance(denominator, int):
                raise TypeError("Invalid type for `denominator`, type has to be `int`")

        self._denominator = denominator

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DisplayAspectRatio):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.muxings.chunked_text.chunked_text_api import ChunkedTextApi
from bitmovin_api_sdk.encoding.encodings.muxings.chunked_text.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.chunked_text.chunked_text_muxing_list_query_params import ChunkedTextMuxingListQueryParams



from bitmovin_api_sdk.encoding.error_definitions.error_definitions_api import ErrorDefinitionsApi
from bitmovin_api_sdk.encoding.error_definitions.encoding_error_definition_list_query_params import EncodingErrorDefinitionListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class MediaStream(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 position=None,
                 duration=None,
                 codec=None):
        # type: (string_types, int, float, string_types) -> None
        super(MediaStream, self).__init__(id_=id_)

        self._position = None
        self._duration = None
        self._codec = None
        self.discriminator = None

        if position is not None:
            self.position = position
        if duration is not None:
            self.duration = duration
        if codec is not None:
            self.codec = codec

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(MediaStream, self), 'openapi_types'):
            types = getattr(super(MediaStream, self), 'openapi_types')

        types.update({
            'position': 'int',
            'duration': 'float',
            'codec': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(MediaStream, self), 'attribute_map'):
            attributes = getattr(super(MediaStream, self), 'attribute_map')

        attributes.update({
            'position': 'position',
            'duration': 'duration',
            'codec': 'codec'
        })
        return attributes

    @property
    def position(self):
        # type: () -> int
        """Gets the position of this MediaStream.

        Position of the stream in the media, starting from 0.

        :return: The position of this MediaStream.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        # type: (int) -> None
        """Sets the position of this MediaStream.

        Position of the stream in the media, starting from 0.

        :param position: The position of this MediaStream.
        :type: int
        """

        if position is not None:
            if position is not None and position < 0:
                raise ValueError("Invalid value for `position`, must be a value greater than or equal to `0`")
            if not isinstance(position, int):
                raise TypeError("Invalid type for `position`, type has to be `int`")

        self._position = position

    @property
    def duration(self):
        # type: () -> float
        """Gets the duration of this MediaStream.

        Duration of the stream in seconds

        :return: The duration of this MediaStream.
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        # type: (float) -> None
        """Sets the duration of this MediaStream.

        Duration of the stream in seconds

        :param duration: The duration of this MediaStream.
        :type: float
        """

        if duration is not None:
            if not isinstance(duration, (float, int)):
                raise TypeError("Invalid type for `duration`, type has to be `float`")

        self._duration = duration

    @property
    def codec(self):
        # type: () -> string_types
        """Gets the codec of this MediaStream.

        Codec of the stream

        :return: The codec of this MediaStream.
        :rtype: string_types
        """
        return self._codec

    @codec.setter
    def codec(self, codec):
        # type: (string_types) -> None
        """Sets the codec of this MediaStream.

        Codec of the stream

        :param codec: The codec of this MediaStream.
        :type: string_types
        """

        if codec is not None:
            if not isinstance(codec, string_types):
                raise TypeError("Invalid type for `codec`, type has to be `string_types`")

        self._codec = codec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(MediaStream, self), "to_dict"):
            result = super(MediaStream, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MediaStream):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.tenant import Tenant
from bitmovin_api_sdk.account.organizations.groups.tenants.tenant_list_query_params import TenantListQueryParams


class TenantsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(TenantsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, organization_id, group_id, tenant, **kwargs):
        # type: (string_types, string_types, Tenant, dict) -> Tenant
        """Add Tenant to Group

        :param organization_id: Id of the organization
        :type organization_id: string_types, required
        :param group_id: Id of the group
        :type group_id: string_types, required
        :param tenant: Tenant details
        :type tenant: Tenant, required
        :return: Tenant details
        :rtype: Tenant
        """

        return self.api_client.post(
            '/account/organizations/{organization_id}/groups/{group_id}/tenants',
            tenant,
            path_params={'organization_id': organization_id, 'group_id': group_id},
            type=Tenant,
            **kwargs
        )

    def delete(self, organization_id, group_id, tenant_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> BitmovinResponse
        """Delete Tenant

        :param organization_id: Id of the organization
        :type organization_id: string_types, required
        :param group_id: Id of the group
        :type group_id: string_types, required
        :param tenant_id: Id of the tenant.
        :type tenant_id: string_types, required
        :return: Id of the group
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/account/organizations/{organization_id}/groups/{group_id}/tenants/{tenant_id}',
            path_params={'organization_id': organization_id, 'group_id': group_id, 'tenant_id': tenant_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, organization_id, group_id, tenant_id, **kwargs):
        # type: (string_types, string_types, string_types, dict) -> Tenant
        """Tenant Details

        :param organization_id: Id of the organization
        :type organization_id: string_types, required
        :param group_id: Id of the group
        :type group_id: string_types, required
        :param tenant_id: Id of the tenant.
        :type tenant_id: string_types, required
        :return: Tenant details
        :rtype: Tenant
        """

        return self.api_client.get(
            '/account/organizations/{organization_id}/groups/{group_id}/tenants/{tenant_id}',
            path_params={'organization_id': organization_id, 'group_id': group_id, 'tenant_id': tenant_id},
            type=Tenant,
            **kwargs
        )

    def list(self, organization_id, group_id, query_params=None, **kwargs):
        # type: (string_types, string_types, TenantListQueryParams, dict) -> Tenant
        """List Tenants

        :param organization_id: Id of the organization
        :type organization_id: string_types, required
        :param group_id: Id of the group
        :type group_id: string_types, required
        :param query_params: Query parameters
        :type query_params: TenantListQueryParams
        :return: Service specific result
        :rtype: Tenant
        """

        return self.api_client.get(
            '/account/organizations/{organization_id}/groups/{group_id}/tenants',
            path_params={'organization_id': organization_id, 'group_id': group_id},
            query_params=query_params,
            pagination_response=True,
            type=Tenant,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dash_edition_compatibility import DashEditionCompatibility
from bitmovin_api_sdk.models.dash_manifest import DashManifest
from bitmovin_api_sdk.models.dash_manifest_default_version import DashManifestDefaultVersion
from bitmovin_api_sdk.models.dash_profile import DashProfile
from bitmovin_api_sdk.models.manifest_type import ManifestType
from bitmovin_api_sdk.models.status import Status
import pprint
import six


class DashManifestDefault(DashManifest):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 type_=None,
                 outputs=None,
                 status=None,
                 profile=None,
                 manifest_name=None,
                 namespaces=None,
                 utc_timings=None,
                 dash_edition_compatibility=None,
                 encoding_id=None,
                 version=None,
                 periods=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, ManifestType, list[EncodingOutput], Status, DashProfile, string_types, list[XmlNamespace], list[UtcTiming], DashEditionCompatibility, string_types, DashManifestDefaultVersion, list[DefaultDashManifestPeriod]) -> None
        super(DashManifestDefault, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, type_=type_, outputs=outputs, status=status, profile=profile, manifest_name=manifest_name, namespaces=namespaces, utc_timings=utc_timings, dash_edition_compatibility=dash_edition_compatibility)

        self._encoding_id = None
        self._version = None
        self._periods = list()
        self.discriminator = None

        if encoding_id is not None:
            self.encoding_id = encoding_id
        if version is not None:
            self.version = version
        if periods is not None:
            self.periods = periods

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(DashManifestDefault, self), 'openapi_types'):
            types = getattr(super(DashManifestDefault, self), 'openapi_types')

        types.update({
            'encoding_id': 'string_types',
            'version': 'DashManifestDefaultVersion',
            'periods': 'list[DefaultDashManifestPeriod]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(DashManifestDefault, self), 'attribute_map'):
            attributes = getattr(super(DashManifestDefault, self), 'attribute_map')

        attributes.update({
            'encoding_id': 'encodingId',
            'version': 'version',
            'periods': 'periods'
        })
        return attributes

    @property
    def encoding_id(self):
        # type: () -> string_types
        """Gets the encoding_id of this DashManifestDefault.

        The id of the encoding to create a default manifest from. Required: encodingId or periods

        :return: The encoding_id of this DashManifestDefault.
        :rtype: string_types
        """
        return self._encoding_id

    @encoding_id.setter
    def encoding_id(self, encoding_id):
        # type: (string_types) -> None
        """Sets the encoding_id of this DashManifestDefault.

        The id of the encoding to create a default manifest from. Required: encodingId or periods

        :param encoding_id: The encoding_id of this DashManifestDefault.
        :type: string_types
        """

        if encoding_id is not None:
            if not isinstance(encoding_id, string_types):
                raise TypeError("Invalid type for `encoding_id`, type has to be `string_types`")

        self._encoding_id = encoding_id

    @property
    def version(self):
        # type: () -> DashManifestDefaultVersion
        """Gets the version of this DashManifestDefault.

        The version of the default manifest generator

        :return: The version of this DashManifestDefault.
        :rtype: DashManifestDefaultVersion
        """
        return self._version

    @version.setter
    def version(self, version):
        # type: (DashManifestDefaultVersion) -> None
        """Sets the version of this DashManifestDefault.

        The version of the default manifest generator

        :param version: The version of this DashManifestDefault.
        :type: DashManifestDefaultVersion
        """

        if version is not None:
            if not isinstance(version, DashManifestDefaultVersion):
                raise TypeError("Invalid type for `version`, type has to be `DashManifestDefaultVersion`")

        self._version = version

    @property
    def periods(self):
        # type: () -> list[DefaultDashManifestPeriod]
        """Gets the periods of this DashManifestDefault.

        Adds a period for every item. Required: encodingId or periods

        :return: The periods of this DashManifestDefault.
        :rtype: list[DefaultDashManifestPeriod]
        """
        return self._periods

    @periods.setter
    def periods(self, periods):
        # type: (list) -> None
        """Sets the periods of this DashManifestDefault.

        Adds a period for every item. Required: encodingId or periods

        :param periods: The periods of this DashManifestDefault.
        :type: list[DefaultDashManifestPeriod]
        """

        if periods is not None:
            if not isinstance(periods, list):
                raise TypeError("Invalid type for `periods`, type has to be `list[DefaultDashManifestPeriod]`")

        self._periods = periods

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(DashManifestDefault, self), "to_dict"):
            result = super(DashManifestDefault, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashManifestDefault):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DolbyAtmosMeteringMode(Enum):
    ITU_R_BS_1770_1 = "ITU-R BS.1770-1"
    ITU_R_BS_1770_2 = "ITU-R BS.1770-2"
    ITU_R_BS_1770_3 = "ITU-R BS.1770-3"
    ITU_R_BS_1770_4 = "ITU-R BS.1770-4"
    LEQ_A = "Leq (A)"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class BasicMediaInfo(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 group_id=None,
                 language=None,
                 assoc_language=None,
                 name=None,
                 is_default=None,
                 autoselect=None,
                 characteristics=None):
        # type: (string_types, string_types, string_types, string_types, string_types, bool, bool, list[string_types]) -> None
        super(BasicMediaInfo, self).__init__(id_=id_)

        self._group_id = None
        self._language = None
        self._assoc_language = None
        self._name = None
        self._is_default = None
        self._autoselect = None
        self._characteristics = list()
        self.discriminator = None

        if group_id is not None:
            self.group_id = group_id
        if language is not None:
            self.language = language
        if assoc_language is not None:
            self.assoc_language = assoc_language
        if name is not None:
            self.name = name
        if is_default is not None:
            self.is_default = is_default
        if autoselect is not None:
            self.autoselect = autoselect
        if characteristics is not None:
            self.characteristics = characteristics

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(BasicMediaInfo, self), 'openapi_types'):
            types = getattr(super(BasicMediaInfo, self), 'openapi_types')

        types.update({
            'group_id': 'string_types',
            'language': 'string_types',
            'assoc_language': 'string_types',
            'name': 'string_types',
            'is_default': 'bool',
            'autoselect': 'bool',
            'characteristics': 'list[string_types]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(BasicMediaInfo, self), 'attribute_map'):
            attributes = getattr(super(BasicMediaInfo, self), 'attribute_map')

        attributes.update({
            'group_id': 'groupId',
            'language': 'language',
            'assoc_language': 'assocLanguage',
            'name': 'name',
            'is_default': 'isDefault',
            'autoselect': 'autoselect',
            'characteristics': 'characteristics'
        })
        return attributes

    @property
    def group_id(self):
        # type: () -> string_types
        """Gets the group_id of this BasicMediaInfo.

        The value is a quoted-string which specifies the group to which the Rendition belongs. (required)

        :return: The group_id of this BasicMediaInfo.
        :rtype: string_types
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        # type: (string_types) -> None
        """Sets the group_id of this BasicMediaInfo.

        The value is a quoted-string which specifies the group to which the Rendition belongs. (required)

        :param group_id: The group_id of this BasicMediaInfo.
        :type: string_types
        """

        if group_id is not None:
            if not isinstance(group_id, string_types):
                raise TypeError("Invalid type for `group_id`, type has to be `string_types`")

        self._group_id = group_id

    @property
    def language(self):
        # type: () -> string_types
        """Gets the language of this BasicMediaInfo.

        Primary language in the rendition.

        :return: The language of this BasicMediaInfo.
        :rtype: string_types
        """
        return self._language

    @language.setter
    def language(self, language):
        # type: (string_types) -> None
        """Sets the language of this BasicMediaInfo.

        Primary language in the rendition.

        :param language: The language of this BasicMediaInfo.
        :type: string_types
        """

        if language is not None:
            if not isinstance(language, string_types):
                raise TypeError("Invalid type for `language`, type has to be `string_types`")

        self._language = language

    @property
    def assoc_language(self):
        # type: () -> string_types
        """Gets the assoc_language of this BasicMediaInfo.

        Identifies a language that is associated with the Rendition.

        :return: The assoc_language of this BasicMediaInfo.
        :rtype: string_types
        """
        return self._assoc_language

    @assoc_language.setter
    def assoc_language(self, assoc_language):
        # type: (string_types) -> None
        """Sets the assoc_language of this BasicMediaInfo.

        Identifies a language that is associated with the Rendition.

        :param assoc_language: The assoc_language of this BasicMediaInfo.
        :type: string_types
        """

        if assoc_language is not None:
            if not isinstance(assoc_language, string_types):
                raise TypeError("Invalid type for `assoc_language`, type has to be `string_types`")

        self._assoc_language = assoc_language

    @property
    def name(self):
        # type: () -> string_types
        """Gets the name of this BasicMediaInfo.

        Human readable description of the rendition. (required)

        :return: The name of this BasicMediaInfo.
        :rtype: string_types
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (string_types) -> None
        """Sets the name of this BasicMediaInfo.

        Human readable description of the rendition. (required)

        :param name: The name of this BasicMediaInfo.
        :type: string_types
        """

        if name is not None:
            if not isinstance(name, string_types):
                raise TypeError("Invalid type for `name`, type has to be `string_types`")

        self._name = name

    @property
    def is_default(self):
        # type: () -> bool
        """Gets the is_default of this BasicMediaInfo.

        If set to true, the client SHOULD play this Rendition of the content in the absence of information from the user.

        :return: The is_default of this BasicMediaInfo.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        # type: (bool) -> None
        """Sets the is_default of this BasicMediaInfo.

        If set to true, the client SHOULD play this Rendition of the content in the absence of information from the user.

        :param is_default: The is_default of this BasicMediaInfo.
        :type: bool
        """

        if is_default is not None:
            if not isinstance(is_default, bool):
                raise TypeError("Invalid type for `is_default`, type has to be `bool`")

        self._is_default = is_default

    @property
    def autoselect(self):
        # type: () -> bool
        """Gets the autoselect of this BasicMediaInfo.

        If set to true, the client MAY choose to play this Rendition in the absence of explicit user preference.

        :return: The autoselect of this BasicMediaInfo.
        :rtype: bool
        """
        return self._autoselect

    @autoselect.setter
    def autoselect(self, autoselect):
        # type: (bool) -> None
        """Sets the autoselect of this BasicMediaInfo.

        If set to true, the client MAY choose to play this Rendition in the absence of explicit user preference.

        :param autoselect: The autoselect of this BasicMediaInfo.
        :type: bool
        """

        if autoselect is not None:
            if not isinstance(autoselect, bool):
                raise TypeError("Invalid type for `autoselect`, type has to be `bool`")

        self._autoselect = autoselect

    @property
    def characteristics(self):
        # type: () -> list[string_types]
        """Gets the characteristics of this BasicMediaInfo.

        Contains Uniform Type Identifiers

        :return: The characteristics of this BasicMediaInfo.
        :rtype: list[string_types]
        """
        return self._characteristics

    @characteristics.setter
    def characteristics(self, characteristics):
        # type: (list) -> None
        """Sets the characteristics of this BasicMediaInfo.

        Contains Uniform Type Identifiers

        :param characteristics: The characteristics of this BasicMediaInfo.
        :type: list[string_types]
        """

        if characteristics is not None:
            if not isinstance(characteristics, list):
                raise TypeError("Invalid type for `characteristics`, type has to be `list[string_types]`")

        self._characteristics = characteristics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(BasicMediaInfo, self), "to_dict"):
            result = super(BasicMediaInfo, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BasicMediaInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.manifests.dash.dash_api import DashApi
from bitmovin_api_sdk.encoding.manifests.dash.default.default_api import DefaultApi
from bitmovin_api_sdk.encoding.manifests.dash.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.manifests.dash.periods.periods_api import PeriodsApi
from bitmovin_api_sdk.encoding.manifests.dash.dash_manifest_list_query_params import DashManifestListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.smooth_streaming_representation import SmoothStreamingRepresentation
from bitmovin_api_sdk.encoding.manifests.smooth.representations.mp4.smooth_streaming_representation_list_query_params import SmoothStreamingRepresentationListQueryParams


class Mp4Api(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(Mp4Api, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, manifest_id, smooth_streaming_representation, **kwargs):
        # type: (string_types, SmoothStreamingRepresentation, dict) -> SmoothStreamingRepresentation
        """Add MP4 Representation to Smooth Streaming Manifest

        :param manifest_id: Id of the Smooth Streaming manifest.
        :type manifest_id: string_types, required
        :param smooth_streaming_representation: The MP4 Representation to be added
        :type smooth_streaming_representation: SmoothStreamingRepresentation, required
        :return: Smooth Streaming manifest
        :rtype: SmoothStreamingRepresentation
        """

        return self.api_client.post(
            '/encoding/manifests/smooth/{manifest_id}/representations/mp4',
            smooth_streaming_representation,
            path_params={'manifest_id': manifest_id},
            type=SmoothStreamingRepresentation,
            **kwargs
        )

    def delete(self, manifest_id, representation_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Smooth Streaming MP4 Representation

        :param manifest_id: Id of the Smooth Streaming manifest.
        :type manifest_id: string_types, required
        :param representation_id: Id of the MP4 representation.
        :type representation_id: string_types, required
        :return: Id of the representation
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/manifests/smooth/{manifest_id}/representations/mp4/{representation_id}',
            path_params={'manifest_id': manifest_id, 'representation_id': representation_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, manifest_id, representation_id, **kwargs):
        # type: (string_types, string_types, dict) -> SmoothStreamingRepresentation
        """Smooth Streaming MP4 Representation Details

        :param manifest_id: Id of the Smooth Streaming manifest.
        :type manifest_id: string_types, required
        :param representation_id: Id of the MP4 representation.
        :type representation_id: string_types, required
        :return: MP4 representation details
        :rtype: SmoothStreamingRepresentation
        """

        return self.api_client.get(
            '/encoding/manifests/smooth/{manifest_id}/representations/mp4/{representation_id}',
            path_params={'manifest_id': manifest_id, 'representation_id': representation_id},
            type=SmoothStreamingRepresentation,
            **kwargs
        )

    def list(self, manifest_id, query_params=None, **kwargs):
        # type: (string_types, SmoothStreamingRepresentationListQueryParams, dict) -> SmoothStreamingRepresentation
        """List MP4 Representation

        :param manifest_id: Id of the Smooth Streaming manifest.
        :type manifest_id: string_types, required
        :param query_params: Query parameters
        :type query_params: SmoothStreamingRepresentationListQueryParams
        :return: MP4 Representation results
        :rtype: SmoothStreamingRepresentation
        """

        return self.api_client.get(
            '/encoding/manifests/smooth/{manifest_id}/representations/mp4',
            path_params={'manifest_id': manifest_id},
            query_params=query_params,
            pagination_response=True,
            type=SmoothStreamingRepresentation,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.stream import Stream
from bitmovin_api_sdk.encoding.encodings.streams.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.streams.input.input_api import InputApi
from bitmovin_api_sdk.encoding.encodings.streams.inputs.inputs_api import InputsApi
from bitmovin_api_sdk.encoding.encodings.streams.filters.filters_api import FiltersApi
from bitmovin_api_sdk.encoding.encodings.streams.burn_in_subtitles.burn_in_subtitles_api import BurnInSubtitlesApi
from bitmovin_api_sdk.encoding.encodings.streams.watermarking.watermarking_api import WatermarkingApi
from bitmovin_api_sdk.encoding.encodings.streams.captions.captions_api import CaptionsApi
from bitmovin_api_sdk.encoding.encodings.streams.bifs.bifs_api import BifsApi
from bitmovin_api_sdk.encoding.encodings.streams.hdr.hdr_api import HdrApi
from bitmovin_api_sdk.encoding.encodings.streams.thumbnails.thumbnails_api import ThumbnailsApi
from bitmovin_api_sdk.encoding.encodings.streams.sprites.sprites_api import SpritesApi
from bitmovin_api_sdk.encoding.encodings.streams.qc.qc_api import QcApi
from bitmovin_api_sdk.encoding.encodings.streams.stream_list_query_params import StreamListQueryParams


class StreamsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(StreamsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.input = InputApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.inputs = InputsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.filters = FiltersApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.burn_in_subtitles = BurnInSubtitlesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.watermarking = WatermarkingApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.captions = CaptionsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.bifs = BifsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.hdr = HdrApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.thumbnails = ThumbnailsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.sprites = SpritesApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.qc = QcApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, stream, **kwargs):
        # type: (string_types, Stream, dict) -> Stream
        """Add Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream: The Stream to be created
        :type stream: Stream, required
        :return: Stream
        :rtype: Stream
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/streams',
            stream,
            path_params={'encoding_id': encoding_id},
            type=Stream,
            **kwargs
        )

    def delete(self, encoding_id, stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :return: Id of the stream
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> Stream
        """Stream Details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param stream_id: Id of the stream.
        :type stream_id: string_types, required
        :return: Stream
        :rtype: Stream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams/{stream_id}',
            path_params={'encoding_id': encoding_id, 'stream_id': stream_id},
            type=Stream,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, StreamListQueryParams, dict) -> Stream
        """List Streams

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: StreamListQueryParams
        :return: List of streams
        :rtype: Stream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/streams',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=Stream,
            **kwargs
        )



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.player_third_party_licensing import PlayerThirdPartyLicensing
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class ThirdPartyLicensingApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(ThirdPartyLicensingApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, license_id, player_third_party_licensing, **kwargs):
        # type: (string_types, PlayerThirdPartyLicensing, dict) -> PlayerThirdPartyLicensing
        """Enable Third Party Licensing

        :param license_id: Id of the Player License
        :type license_id: string_types, required
        :param player_third_party_licensing: Third Party Licensing settings to apply to Player License
        :type player_third_party_licensing: PlayerThirdPartyLicensing, required
        :return: Third party licensing details
        :rtype: PlayerThirdPartyLicensing
        """

        return self.api_client.post(
            '/player/licenses/{license_id}/third-party-licensing',
            player_third_party_licensing,
            path_params={'license_id': license_id},
            type=PlayerThirdPartyLicensing,
            **kwargs
        )

    def delete(self, license_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Third Party Licensing Configuration

        :param license_id: Id of the Player License
        :type license_id: string_types, required
        :return: Id of the deleted Third Party Licensing Configuration
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/player/licenses/{license_id}/third-party-licensing',
            path_params={'license_id': license_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, license_id, **kwargs):
        # type: (string_types, dict) -> PlayerThirdPartyLicensing
        """Get Third Party Licensing Configuration

        :param license_id: Id of the Player License
        :type license_id: string_types, required
        :return: Third party licensing details
        :rtype: PlayerThirdPartyLicensing
        """

        return self.api_client.get(
            '/player/licenses/{license_id}/third-party-licensing',
            path_params={'license_id': license_id},
            type=PlayerThirdPartyLicensing,
            **kwargs
        )



from bitmovin_api_sdk.encoding.outputs.s3.s3_api import S3Api
from bitmovin_api_sdk.encoding.outputs.s3.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.s3.s3_output_list_query_params import S3OutputListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.models.unsharp_filter import UnsharpFilter
from bitmovin_api_sdk.encoding.filters.unsharp.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.unsharp.unsharp_filter_list_query_params import UnsharpFilterListQueryParams


class UnsharpApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(UnsharpApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, unsharp_filter, **kwargs):
        # type: (UnsharpFilter, dict) -> UnsharpFilter
        """Create Unsharp Filter

        :param unsharp_filter: The Unsharp Filter to be created
        :type unsharp_filter: UnsharpFilter, required
        :return: Unsharp Filter details
        :rtype: UnsharpFilter
        """

        return self.api_client.post(
            '/encoding/filters/unsharp',
            unsharp_filter,
            type=UnsharpFilter,
            **kwargs
        )

    def delete(self, filter_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Unsharp Filter

        :param filter_id: Id of the unsharp filter
        :type filter_id: string_types, required
        :return: Id of the unsharp filter.
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/filters/unsharp/{filter_id}',
            path_params={'filter_id': filter_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, filter_id, **kwargs):
        # type: (string_types, dict) -> UnsharpFilter
        """Unsharp Filter Details

        :param filter_id: Id of the unsharp filter
        :type filter_id: string_types, required
        :return: Unsharp Filter details
        :rtype: UnsharpFilter
        """

        return self.api_client.get(
            '/encoding/filters/unsharp/{filter_id}',
            path_params={'filter_id': filter_id},
            type=UnsharpFilter,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (UnsharpFilterListQueryParams, dict) -> UnsharpFilter
        """List Unsharp Filters

        :param query_params: Query parameters
        :type query_params: UnsharpFilterListQueryParams
        :return: List of Unsharp Filters
        :rtype: UnsharpFilter
        """

        return self.api_client.get(
            '/encoding/filters/unsharp',
            query_params=query_params,
            pagination_response=True,
            type=UnsharpFilter,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class RateDistortionLevelForQuantization(Enum):
    DISABLED = "DISABLED"
    LEVELS = "LEVELS"
    LEVELS_AND_CODING_GROUPS = "LEVELS_AND_CODING_GROUPS"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.filter import Filter
import pprint
import six


class EbuR128SinglePassFilter(Filter):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 integrated_loudness=None,
                 loudness_range=None,
                 maximum_true_peak_level=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, float, float, float) -> None
        super(EbuR128SinglePassFilter, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._integrated_loudness = None
        self._loudness_range = None
        self._maximum_true_peak_level = None
        self.discriminator = None

        if integrated_loudness is not None:
            self.integrated_loudness = integrated_loudness
        if loudness_range is not None:
            self.loudness_range = loudness_range
        if maximum_true_peak_level is not None:
            self.maximum_true_peak_level = maximum_true_peak_level

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(EbuR128SinglePassFilter, self), 'openapi_types'):
            types = getattr(super(EbuR128SinglePassFilter, self), 'openapi_types')

        types.update({
            'integrated_loudness': 'float',
            'loudness_range': 'float',
            'maximum_true_peak_level': 'float'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(EbuR128SinglePassFilter, self), 'attribute_map'):
            attributes = getattr(super(EbuR128SinglePassFilter, self), 'attribute_map')

        attributes.update({
            'integrated_loudness': 'integratedLoudness',
            'loudness_range': 'loudnessRange',
            'maximum_true_peak_level': 'maximumTruePeakLevel'
        })
        return attributes

    @property
    def integrated_loudness(self):
        # type: () -> float
        """Gets the integrated_loudness of this EbuR128SinglePassFilter.

        Set the targeted integrated loudness value. Range is from '-70.0' to '-5.0'. Default value is '-24.0'. Value is measured in LUFS (Loudness Units, referenced to Full Scale)

        :return: The integrated_loudness of this EbuR128SinglePassFilter.
        :rtype: float
        """
        return self._integrated_loudness

    @integrated_loudness.setter
    def integrated_loudness(self, integrated_loudness):
        # type: (float) -> None
        """Sets the integrated_loudness of this EbuR128SinglePassFilter.

        Set the targeted integrated loudness value. Range is from '-70.0' to '-5.0'. Default value is '-24.0'. Value is measured in LUFS (Loudness Units, referenced to Full Scale)

        :param integrated_loudness: The integrated_loudness of this EbuR128SinglePassFilter.
        :type: float
        """

        if integrated_loudness is not None:
            if not isinstance(integrated_loudness, (float, int)):
                raise TypeError("Invalid type for `integrated_loudness`, type has to be `float`")

        self._integrated_loudness = integrated_loudness

    @property
    def loudness_range(self):
        # type: () -> float
        """Gets the loudness_range of this EbuR128SinglePassFilter.

        Set the targeted loudness range target. Range is from '1.0' to '20.0'. Default value is '7.0'. Loudness range measures the variation of loudness on a macroscopic time-scale in units of LU (Loudness Units). For programmes shorter than 1 minute, the use of the measure Loudness Range is not recommended due to too few data points (Loudness Range is based on the Short-term-Loudness values (3-seconds-window)).

        :return: The loudness_range of this EbuR128SinglePassFilter.
        :rtype: float
        """
        return self._loudness_range

    @loudness_range.setter
    def loudness_range(self, loudness_range):
        # type: (float) -> None
        """Sets the loudness_range of this EbuR128SinglePassFilter.

        Set the targeted loudness range target. Range is from '1.0' to '20.0'. Default value is '7.0'. Loudness range measures the variation of loudness on a macroscopic time-scale in units of LU (Loudness Units). For programmes shorter than 1 minute, the use of the measure Loudness Range is not recommended due to too few data points (Loudness Range is based on the Short-term-Loudness values (3-seconds-window)).

        :param loudness_range: The loudness_range of this EbuR128SinglePassFilter.
        :type: float
        """

        if loudness_range is not None:
            if not isinstance(loudness_range, (float, int)):
                raise TypeError("Invalid type for `loudness_range`, type has to be `float`")

        self._loudness_range = loudness_range

    @property
    def maximum_true_peak_level(self):
        # type: () -> float
        """Gets the maximum_true_peak_level of this EbuR128SinglePassFilter.

        Set maximum true peak. Range is from '-9.0' to '0.0'. Default value is '-2.0'. Values are measured in dBTP (db True Peak)

        :return: The maximum_true_peak_level of this EbuR128SinglePassFilter.
        :rtype: float
        """
        return self._maximum_true_peak_level

    @maximum_true_peak_level.setter
    def maximum_true_peak_level(self, maximum_true_peak_level):
        # type: (float) -> None
        """Sets the maximum_true_peak_level of this EbuR128SinglePassFilter.

        Set maximum true peak. Range is from '-9.0' to '0.0'. Default value is '-2.0'. Values are measured in dBTP (db True Peak)

        :param maximum_true_peak_level: The maximum_true_peak_level of this EbuR128SinglePassFilter.
        :type: float
        """

        if maximum_true_peak_level is not None:
            if not isinstance(maximum_true_peak_level, (float, int)):
                raise TypeError("Invalid type for `maximum_true_peak_level`, type has to be `float`")

        self._maximum_true_peak_level = maximum_true_peak_level

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(EbuR128SinglePassFilter, self), "to_dict"):
            result = super(EbuR128SinglePassFilter, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EbuR128SinglePassFilter):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
